package com.akamai.mdt.id3tag;

import android.app.Activity;
import android.content.DialogInterface;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.MotionEvent;
import android.view.View;
import android.view.WindowManager;
import android.widget.ProgressBar;
import android.widget.TextView;

import com.akamai.id3tags.ID3TagData;
import com.akamai.id3tags.ID3TagEventListener;
import com.akamai.id3tags.ID3TagExtractorMessageHandler;
import com.akamai.media.IPlayerEventsListener;
import com.akamai.media.VideoPlayerContainer;
import com.akamai.media.VideoPlayerView;
import com.akamai.media.elements.AMPLibraryInfo;
import com.akamai.media.elements.MediaResource;
import com.akamai.media.errors.ErrorType;

public class MainActivity extends Activity
        implements View.OnTouchListener, DialogInterface.OnCancelListener, IPlayerEventsListener, ID3TagEventListener {

    private final static String LOG_TAG = "ID3TagsAMP";
    private final static String LICENSE = "Xun_biQDGlqwOlKxgRiWVK283OnTccVwJNUb2YlYmlbHzgVP5S-3l_bB95rvVLjp_8ZhHd0WA7eE35YilStPFg==";
    private final static String VIDEO_URL = "http://sblanco.mediadev.edgesuite.net/id3/master.m3u8";
    //private final static String VIDEO_URL = "http://qa-apache-testing-ubu-01.dev.kaltura.com/p/1091/sp/109100/playManifest/entryId/0_f8re4ujs/format/applehttp/protocol/http/uiConfId/15089201/a.m3u8";

    private VideoPlayerContainer mVideoContainer;
    private VideoPlayerView mVideoView;
    private ProgressBar mProgressBar;
    private TextView tagsTextView;

    private MediaResource resource;
    private int mCurrentPosition = 0;
    private boolean mWasPlaying = false;

    private ID3TagExtractorMessageHandler id3Handler;


    @Override
    public boolean onFoundID3TagData(ID3TagData data) {
        String id3Tag = data.getText();
        Log.i(LOG_TAG, id3Tag);
        tagsTextView.setText(id3Tag);
        return true;
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        // This prevents the device to go sleep
        getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);

        mProgressBar = (ProgressBar) findViewById(R.id.progressBar);

        mVideoContainer = (VideoPlayerContainer) findViewById(R.id.playerViewCtrl);

        tagsTextView = (TextView) findViewById(R.id.tagsTextView);

        mVideoContainer.addVideoPlayerContainerCallback(new VideoPlayerContainer.VideoPlayerContainerCallback() {
            @Override
            public void onVideoPlayerCreated() {
                String versionMsg = "AMP v" + AMPLibraryInfo.VERSION + " using ID3 tags module v" + ID3TagExtractorMessageHandler.VERSION;
                Log.i(LOG_TAG, versionMsg);
            }

            @Override
            public void onResourceReady(MediaResource mediaResource) {
                resource = mediaResource;

                mVideoView = mVideoContainer.getVideoPlayer();
                mVideoView.setProgressBarControl(mProgressBar);
                mVideoView.setLicense(LICENSE);
                mVideoView.setFullScreen(true);
                mVideoView.setFullScreenMode(VideoPlayerView.FULLSCREEN_MODE_KEEP_ASPECT_RATIO);
                mVideoView.setLogEnabled(true);

                initID3Handler();

                mVideoView.play(resource);
            }

            @Override
            public void onResourceError(ErrorType errorType, Exception exception) {
                Log.e(LOG_TAG, "onResourceError()");
            }
        });

        mVideoContainer.prepareResource(VIDEO_URL);
    }

    private void initID3Handler() {
        id3Handler = new ID3TagExtractorMessageHandler();
        id3Handler.setVideoPlayerView(mVideoView);
        id3Handler.addEventListener(MainActivity.this);
    }

    @Override
    protected void onResume() {
        Log.d("PlayerView", "OnResume");
        if (mWasPlaying) {
            mVideoView.play(resource, mCurrentPosition);
            mWasPlaying = false;
        }
        super.onResume();
    }

    @Override
    protected void onPause() {
        Log.d("PlayerView", "OnPause");

        if ((mVideoView != null)){
            if (mVideoView.isPlaying() || mVideoView.isPaused()) {
                mCurrentPosition = mVideoView.getTimePosition();
                mWasPlaying = true;
            }
            mVideoView.stop();
        }
        super.onPause();
    }

    @Override
    protected void onDestroy() {
        Log.d("PlayerView", "OnDestroy");
        mVideoView.stop();
        mVideoView.onDestroy();
        super.onDestroy();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    @Override
    public boolean onPlayerEvent(int iInEventType) {
        return true;
    }

    @Override
    public boolean onPlayerExtendedEvent(int iInEventType, int arg1, int arg2) {
        if (iInEventType == IPlayerEventsListener.PLAYER_EXTENDED_EVENT_SEEKING_SUCCEDEED) {
            Log.d("Player", "Event Type: PLAYER_EXTENDED_EVENT_SEEKING_SUCCEDED (" + iInEventType + ")");
        }

        return true;
    }

    @Override
    public void onCancel(DialogInterface dialog) {
        finish();
    }

    @Override
    public boolean onTouch(View v, MotionEvent event) {
        return false;
    }

}
